frx_generator library

A code generator for frx_annotation package that generates pattern matching methods for union types in Dart.

This library provides tools to automatically generate extension methods for classes annotated with @FrxAnnotation from the frx_annotation package.

By default, all constructor parameters are included in pattern matching. This behavior can be controlled using the generateAllFields parameter of the @frx annotation.

Classes

FrxGenerator
Generator for creating pattern matching extension methods on classes annotated with @FrxAnnotation.

Extensions

StringExtension on String

Functions

frxBuilder(BuilderOptions options) → Builder
Creates a builder for generating pattern matching extension methods for classes annotated with @FrxAnnotation.